pub fn skill_specific_call_capability(id: &str) -> CapabilityNameExpand description
Returns the per-skill call capability for the skill with the given id.
pub fn skill_specific_call_capability(id: &str) -> CapabilityNameReturns the per-skill call capability for the skill with the given id.