SkillEventSink

Trait SkillEventSink 

pub trait SkillEventSink {
    // Required method
    fn emit(&mut self, cx: &mut Cx, event: Value) -> Result<()>;
}
Sink that receives streaming events emitted during a skill call.

Required Methods

fn emit(&mut self, cx: &mut Cx, event: Value) -> Result<()>

Emits one event produced while a skill call is in progress.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors